@@ -12,8 +12,8 @@ import ROOT
 from quickstats.components.numerics import is_integer
 
 class ExtendedModel(object):
-    def __init__(self, model_name:str, fname:str, ws_name:str,
-                 model_config_name:str, data_name:str, snapshot_names:List[str],
+    def __init__(self, model_name:str, fname:str, ws_name:str="combWS",
+                 model_config_name:str="ModelConfig", data_name:str="combData", snapshot_names:List[str]=["nominalNuis"],
                  binned_likelihood:bool=True, tag_as_measurement:str="pdf_",
                  fix_cache:bool=True, fix_multi:bool=True,
                  interpolation_code:int=-1):
@@ -473,10 +473,69 @@ class ExtendedModel(object):
                 nuis.setError(prefit_variation)
                 nuis.removeRange()    
         return None
-                
-                
-                
-                
+    @staticmethod
+    def to_dataframe(args):
+        import pandas as pd
+        data = [{'Name':i.GetName(), 'Value':i.getVal(), "Constant":i.isConstant(), "Min":i.getMin(), "Max":i.getMax()} for i in args]
+        df = pandas.DataFrame(data)
+        return df
+
+    @staticmethod
+    def get_workspace(fname:str, ws_name:str="combWS"):
+        if not os.path.exists(fname):
+            raise FileNotFoundError('workspace file {} does not exist'.format(fname))
+        file = ROOT.TFile(fname) 
+        if (not file):
+            raise RuntimeError("Something went wrong while loading the root file: {}".format(fname))
+        ws = file.Get(ws_name)
+        if not ws:
+            raise RuntimeError("Something went wrong while loading the workspace: {}".format(ws_name))
+        return ws
+
+    @staticmethod
+    def get_model_config(fname:str, ws_name:str="combWS",  model_config_name:str="ModelConfig"):
+        ws = ExtendedModel.get_workspace(fname, ws_name)
+        model_config = ws.obj(model_config_name)
+        if not model_config:
+            raise RuntimeError('ERROR: Failed to load model config {}'.format(model_config_name))
+        return model_config
+
+    @staticmethod       
+    def get_nuisance_parameters(fname:str, ws_name:str="combWS", model_config_name:str="ModelConfig", as_str=True):
+        model_config = ExtendedModel.get_model_config(fname, ws_name, model_config_name)
+        nuisance_parameters = model_config.GetNuisanceParameters()
+        if not nuisance_parameters:
+            raise RuntimeError('ERROR: Failed to load nuisance parameters')
+        if as_str:
+            return [nuis.GetName() for nuis in nuisance_parameters]                
+        else:
+            return nuisance_parameters
+
+    @staticmethod       
+    def get_global_observables(fname:str, ws_name:str="combWS", model_config_name:str="ModelConfig", as_str=True):
+        model_config = ExtendedModel.get_model_config(fname, ws_name, model_config_name)
+        global_observables = model_config.GetGlobalObservables()
+        if as_str:
+            return [go.GetName() for go in global_observables]                
+        else:
+            return global_observables
+
+    @staticmethod       
+    def get_parameters_of_interest(fname:str, ws_name:str="combWS", model_config_name:str="ModelConfig", as_str=True):
+        model_config = ExtendedModel.get_model_config(fname, ws_name, model_config_name)
+        pois = model_config.GetParametersOfInterest()
+        if as_str:
+            return [poi.GetName() for poi in pois]                
+        else:
+            return pois            
+
+    @staticmethod
+    def get_datasets(fname:str, ws_name:str="combWS", as_str=True):
+        ws = ExtendedModel.get_workspace(fname, ws_name)
+        if as_str:
+            return [data.GetName() for data in ws.allData()]                
+        else:
+            return [data for data in ws.allData()]  
                 
                 
                 
