@@ -11,7 +11,13 @@ def is_integer(s:str):
 
 def array_swap(arr1:np.ndarray, arr2:np.ndarray, indices):
     arr1[indices], arr2[indices] = arr2[indices], arr1[indices]
-    
+
+def df_array_swap(df, col1:str, col2:str, indices=None):
+    if indices is None:
+        df.loc[:, col1], df.loc[:, col2] = df[col2], df[col1]
+    else:
+        df.loc[indices, col1], df.loc[indices, col2] = df[indices][col2], df[indices][col1]
+        
 def reorder_arrays(*arrays, descending:bool=True):
     if descending:
         if not (arrays[0].dtype.type in [np.string_, np.str_]):
@@ -26,4 +32,7 @@ def reorder_arrays(*arrays, descending:bool=True):
         
 def reverse_arrays(*arrays):
     for arr in arrays:
-        arr[:] = arr[::-1] 
\ No newline at end of file
+        arr[:] = arr[::-1] 
+        
+def ceildiv(a, b):
+    return -(-a // b)
\ No newline at end of file
